import { aws_lambda as lambda } from "aws-cdk-lib";
import { Construct } from "constructs";
export interface LambdaConfigProps {
    /**
     * The Lambda Function to be updated.
     *
     * If this points to a specific version, the version qualifier
     * will be ignored, but will be used for invalidation instead
     * of providing a separate nonce value.
     *
     * A Lambda Function can only receive a new version based on
     * the latest version.
     */
    function: lambda.IFunction;
    /**
     * The configuration to be added to the Lambda Function. Must be
     * a valid JSON structure and cannot contain null values since it
     * is not supported by CloudFormation custom resource properties.
     */
    config: Record<string, any>;
    /**
     * Nonce to force new version.
     *
     * If the function provided does not point to a specific
     * version, specify nonce to ensure the function is updated
     * after every change.
     */
    nonce?: string;
}
/**
 * Modify a Lambda Function by adding a config.json file using
 * the provided object, and provide a new version for the
 * Lambda Function.
 */
export declare class LambdaConfig extends Construct {
    readonly version: lambda.IVersion;
    constructor(scope: Construct, id: string, props: LambdaConfigProps);
}
